find_cluster: GPS Cluster Identification

Description Usage Arguments Examples

View source: R/find_cluster.R

Description

This function identifies potential predation sites ("clusters") by using GPS locations from GPS collared carnivores and user defined thresholds.

Usage

1
2
find_cluster(ind = "Cluster Locations", data = data, time_thres = 1,
  dist_thres = 0.05, size = 1)

Arguments

ind

Text for title of figure of cluster locations produced by 'find_cluster'. Defaults to "Cluster Locations"

data

A data.frame that contains 'date', 'Time', 'lat', and 'long' columns

time_thres

Time, measured in days, between GPS locations to be considered as part of a cluster (i.e., 1 = 24 hours)

dist_thres

Distance, measured in kilometers, between GPS points to be considered in a cluster (i.e., 0.05 = 50 meters)

Examples

1
2
3
4
# Identify clusters of GPS locations that occur within 1 day of eachother
# and within 100 meters of eachother.

find_cluster(ind = "Cluster Locations", data = data, time_thres = 1, dist_thres = 0.1, size = 1)

tpetroel/PredClusters documentation built on Feb. 5, 2020, 5:49 p.m.