Description Usage Arguments Examples
This function formats GPS data from Telonics and Vectoronic Collars used in Isle Royale National Park and then identifies potential predation sites ("clusters") from the formated GPS locations and user defined thresholds.
1 2 3 4 | IRwolves(DownloadDate = DownloadDate, CollarID = CollarID,
AnimalID = AnimalID, NextCluster = NextCluster,
ClusterDate = ClusterDate, time_thres = time_thres,
dist_thres = dist_thres)
|
DownloadDate |
The date and folder title in which the raw GPS data are housed, should be formated as DDMONYYYY (i.e., 14MAY2019) |
CollarID |
The individual identifier for each collar preceeded by "Collar" (i.e., Collar32712) |
AnimalID |
The individual identifier for each wolf (i.e., W001F) indicating the wolf number and sex |
NextCluster |
The next number to be assinged for cluster labeling for independent identification, reference Download_Dates.xlsx |
ClusterDate |
The oldest date to be used for the period to identify clusters within (format = "YYYY-MM-DD", i.e., "2019-05-14") |
time_thres |
Time, measured in days, between GPS locations to be considered as part of a cluster (i.e., 1 = 24 hours) |
dist_thres |
Distance, measured in kilometers, between GPS points to be considered in a cluster (i.e., 0.05 = 50 meters) |
1 2 3 4 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.