Description Usage Arguments Examples
This function identifies potential predation sites ("clusters") by using GPS locations from GPS collared carnivores and user defined thresholds.
1 2 | find_cluster(ind = "Cluster Locations", data = data, time_thres = 1,
dist_thres = 0.05, size = 1)
|
ind |
Text for title of figure of cluster locations produced by 'find_cluster'. Defaults to "Cluster Locations" |
data |
A data.frame that contains 'date', 'Time', 'lat', and 'long' columns |
time_thres |
Time, measured in days, between GPS locations to be considered as part of a cluster (i.e., 1 = 24 hours) |
dist_thres |
Distance, measured in kilometers, between GPS points to be considered in a cluster (i.e., 0.05 = 50 meters) |
1 2 3 4 | # Identify clusters of GPS locations that occur within 1 day of eachother
# and within 100 meters of eachother.
find_cluster(ind = "Cluster Locations", data = data, time_thres = 1, dist_thres = 0.1, size = 1)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.